@@ -164,7 +164,7 @@ int ssl_rand_seed(server_rec *s, pool *p, ssl_rsctx_t nCtx, char *prefix)
     ssl_log(s, SSL_LOG_INFO, "%sSeeding PRNG with %d bytes of entropy", prefix, nDone);
 
 #if SSL_LIBRARY_VERSION >= 0x00905100
-    if (RAND_status == 0)
+    if (RAND_status() == 0)
         ssl_log(s, SSL_LOG_WARN, "%sPRNG still contains not sufficient entropy!", prefix);
 #endif
     return nDone;
